==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/plcore_8c.js <==
var plcore_8c =
[
    [ "BUFFER2_SIZE", "plcore_8c.html#ae0194ede027b49240cc0a7d722d581ed", null ],
    [ "BUFFER_SIZE", "plcore_8c.html#a6b20d41d6252e9871430c242cb1a56e7", null ],
    [ "DEBUG", "plcore_8c.html#ad72dbcf6d0153db1b8d8a58001feed83", null ],
    [ "dirent", "plcore_8c.html#a89957e9be80ef12a50eb4eca72ecd888", null ],
    [ "DRVSPEC_SIZE", "plcore_8c.html#aeccd9f754e3d81d10b32e0449323bafb", null ],
    [ "N_TextLookupTable", "plcore_8c.html#a43b4218c140030f4050f49fe14af41f4", null ],
    [ "NAMLEN", "plcore_8c.html#abb80c1eb90e546dbdc94f79e74ffd787", null ],
    [ "NEED_PLDEBUG", "plcore_8c.html#ad92ef941bb38ab1d2af3bce830fd47c9", null ],
    [ "AT_BOP", "plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55bacef624e37a53fb2a68d5c9a08b8a7ccf", null ],
    [ "DRAWING", "plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba958d99ff23a05900a8e5cf1a56055098", null ],
    [ "AT_EOP", "plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba74ab759c0ff9e51f5df3638a75023e6d", null ],
    [ "c_plcpstrm", "plcore_8c.html#a808e7856a0bef6d71c2309abea207c78", null ],
    [ "c_plend", "plcore_8c.html#a057806120a84ea1da3ffef67bff47491", null ],
    [ "c_plend1", "plcore_8c.html#a82d7eca932a870b8724abf64609be0ce", null ],
    [ "c_plfamadv", "plcore_8c.html#ad03888fe21e744719a5215b2f71b0516", null ],
    [ "c_plflush", "plcore_8c.html#aa68be25daff0516a7e2a0fac0bdfdd9a", null ],
    [ "c_plfontld", "plcore_8c.html#adca30e3b9bfef3b0ac9bcb394e15552c", null ],
    [ "c_plgchr", "plcore_8c.html#a63e2da015640c52a9999c55342b646fc", null ],
    [ "c_plgcompression", "plcore_8c.html#a9b95f1be421f4ffb0ecdd690acc51991", null ],
    [ "c_plgdev", "plcore_8c.html#a730e264140174728e5a9370500dd98b9", null ],
    [ "c_plgdidev", "plcore_8c.html#a148607d52aba56ef94c79a572e72749c", null ],
    [ "c_plgdiori", "plcore_8c.html#af7d3028d40a2a370eaf59b252e70129d", null ],
    [ "c_plgdiplt", "plcore_8c.html#ab7394daabcb9894bf7805308428c71e6", null ],
    [ "c_plgfam", "plcore_8c.html#a7601ac2a53c8ee1385cace0dc8a17d8b", null ],
    [ "c_plgfci", "plcore_8c.html#a83276fc9443a12048337c947819acea3", null ],
    [ "c_plgfnam", "plcore_8c.html#a75a7c204e1e884ee546e0baf88917f54", null ],
    [ "c_plglevel", "plcore_8c.html#a0c11fe456b55f9f0062415101cb9dfc8", null ],
    [ "c_plgpage", "plcore_8c.html#ad9555920fc7673920b6862e38d049191", null ],
    [ "c_plgstrm", "plcore_8c.html#aa6ecda5740335b215a4c6ec05aefe2fc", null ],
    [ "c_plgver", "plcore_8c.html#a2f50780df4b008a23d5c881641bc4838", null ],
    [ "c_plgvpd", "plcore_8c.html#ae5b0ed045773267243e3c74dd6526ae6", null ],
    [ "c_plgvpw", "plcore_8c.html#a64c2cee6f05cffdd2bc9c8b85c94b662", null ],
    [ "c_plgxax", "plcore_8c.html#a7e9b55b0ec2ae5525591f6fede113a9e", null ],
    [ "c_plgyax", "plcore_8c.html#ae147ba26e63df579fc9434c6c4cbc3cd", null ],
    [ "c_plgzax", "plcore_8c.html#a720bd62d527c1db65f35b344c03140e9", null ],
    [ "c_plinit", "plcore_8c.html#ab4936c1ab86820efcc43ba6d2d3e98bd", null ],
    [ "c_plmkstrm", "plcore_8c.html#ad60759694b61589b021ed95fe5299be7", null ],
    [ "c_plprec", "plcore_8c.html#ab2ffc34fab68c711d27aa721b0153d13", null ],
    [ "c_plreplot", "plcore_8c.html#a521895943ac77a578e66673a7a26ad2a", null ],
    [ "c_plscompression", "plcore_8c.html#a1ff4a020fb7e8ba96cb65c1749c077dd", null ],
    [ "c_plsdev", "plcore_8c.html#a9a13e7e0f04135f388717f627b6ed322", null ],
    [ "c_plsdidev", "plcore_8c.html#a3badb62009aef6999810c0d10d20516c", null ],
    [ "c_plsdimap", "plcore_8c.html#a51cb3f6fef775355b2b1580e1307ea26", null ],
    [ "c_plsdiori", "plcore_8c.html#acb67a49f12188daff82a2ec48978d2df", null ],
    [ "c_plsdiplt", "plcore_8c.html#a3bdd5f699d95e79d94e39448172e10c2", null ],
    [ "c_plsdiplz", "plcore_8c.html#ae33ad6c295d7c38c342fc665baee5ba1", null ],
    [ "c_plsesc", "plcore_8c.html#ad34d123d1b509c1da24e3ba401787d43", null ],
    [ "c_plsfam", "plcore_8c.html#a21aa2add88af9fa23a2ea3d031637755", null ],
    [ "c_plsfci", "plcore_8c.html#ac161115689719887c26b967f5ae8cc17", null ],
    [ "c_plsfnam", "plcore_8c.html#a1067db8a7df729d967bd64bbb4db32aa", null ],
    [ "c_plsmem", "plcore_8c.html#a5332cad59cd8e8424274d43a50c869db", null ],
    [ "c_plsmema", "plcore_8c.html#a7c4475f45e1b579af4b147f4cd5df58a", null ],
    [ "c_plsori", "plcore_8c.html#aece5565b63831fdba73b39c9a1f2ea1e", null ],
    [ "c_plspage", "plcore_8c.html#ad12f661799506496b1172332fd00e54f", null ],
    [ "c_plspause", "plcore_8c.html#a6a3b37f7cfbc34a552b4bf20308aa79d", null ],
    [ "c_plsstrm", "plcore_8c.html#aa1e9f431367c59a195f1a8cd9e2227c1", null ],
    [ "c_plssub", "plcore_8c.html#a3f508d621ee47b67d42f656edc0aa9c7", null ],
    [ "c_plstar", "plcore_8c.html#a3d15fa158e627ba1582fbad9271c797b", null ],
    [ "c_plstart", "plcore_8c.html#a294125dcb910f34b5562b6b41175359a", null ],
    [ "c_plstransform", "plcore_8c.html#a1ef1de22d0c5557187f25d20a5193fca", null ],
    [ "c_plsxax", "plcore_8c.html#aca008e616ba21f5d1f51618e0cfe9064", null ],
    [ "c_plsyax", "plcore_8c.html#aae7ebd3c9503d19ef16d9dbe0236e709", null ],
    [ "c_plszax", "plcore_8c.html#a3170cad72924f63f2fe03055f355cb95", null ],
    [ "c_plwidth", "plcore_8c.html#a7e8aa99d537c6041b805f360f5c2b81c", null ],
    [ "calc_didev", "plcore_8c.html#a26b8467bc1909781bdc9d74960d6d238", null ],
    [ "calc_dimap", "plcore_8c.html#a0e92f358a43acd5c2fe68e40433a7b9c", null ],
    [ "calc_diori", "plcore_8c.html#a7a2547ac4d7cc4edab10361ca81f983d", null ],
    [ "calc_diplt", "plcore_8c.html#aaa88349701dbf79cbe3459271e11913d", null ],
    [ "difilt", "plcore_8c.html#a663c143ac825caaef262f7ca77b3c019", null ],
    [ "difilt_clip", "plcore_8c.html#a2e6bd1707a0ea6e38454e364c420eb5e", null ],
    [ "grfill", "plcore_8c.html#a859a0f4ec99bc066171dda65bbd7172c", null ],
    [ "grgradient", "plcore_8c.html#a7498b6e873f50e540504be66a4e8dde0", null ],
    [ "grline", "plcore_8c.html#a05047fa1f14551c0664c4d5192eb4b1a", null ],
    [ "grpolyline", "plcore_8c.html#a1dd1a3d65c1c7e9912c5da15e82f1ba6", null ],
    [ "pl_cpcolor", "plcore_8c.html#a56a35e11c4db4ea3764ae38eae890213", null ],
    [ "pldi_ini", "plcore_8c.html#a5aed70fa2baf0c2959c6023c6c926cd1", null ],
    [ "pldid2pc", "plcore_8c.html#aba7dcb97d5f032a445cfa3ac2c68c999", null ],
    [ "pldip2dc", "plcore_8c.html#a2027ec7ca75362338c45ea442c421436", null ],
    [ "plDispatchSequencer", "plcore_8c.html#a11cad0979d02e025acd0ba8915be12db", null ],
    [ "plgdevlst", "plcore_8c.html#a497b257f1e4edd05ca465a9929c99adb", null ],
    [ "plgDevs", "plcore_8c.html#a06787374c7a4b94b10f6ee71cd9147ab", null ],
    [ "plgesc", "plcore_8c.html#adb3b82d6aa6dae20bcfb8d9b750d385a", null ],
    [ "plgfile", "plcore_8c.html#ad3cb9a03dc019cb768badd38f26bce13", null ],
    [ "plgFileDevs", "plcore_8c.html#ae06fd6c139fb7f7927d28d26ee72adbd", null ],
    [ "plgpls", "plcore_8c.html#a5225c4de186e1a9dc679dc5c05551afb", null ],
    [ "plInBuildTree", "plcore_8c.html#af75db95bfc15fb87921f6ef173d13913", null ],
    [ "plInitDispatchTable", "plcore_8c.html#a747167c361c0eb00627c064f7f9c1eda", null ],
    [ "pllib_devinit", "plcore_8c.html#ae6619e8f9a247bb9f9eac77a2960cd8a", null ],
    [ "pllib_init", "plcore_8c.html#a091b5e6a195184c0cdde351670ed27b0", null ],
    [ "plLoadDriver", "plcore_8c.html#aef0054e2662ce74c5245fbdfae25bd3f", null ],
    [ "plP_bop", "plcore_8c.html#a2a29b38531e5884f2380d3e4b213ed8b", null ],
    [ "plP_checkdriverinit", "plcore_8c.html#aca45ddfcca5aed11ab19be6911e4ebc1", null ],
    [ "plP_eop", "plcore_8c.html#a385cdde6b350434e911fb63b27f5c026", null ],
    [ "plP_esc", "plcore_8c.html#adaaf1b468021f85a88997d5518aa709a", null ],
    [ "plP_fci2hex", "plcore_8c.html#a0d847defa496f25716fd0d031891ac6d", null ],
    [ "plP_fill", "plcore_8c.html#aeb2f57f5e4b95188ab95363895f17573", null ],
    [ "plP_gclp", "plcore_8c.html#aba8054e2bee48e6669cb5143733d1b6d", null ],
    [ "plP_gdom", "plcore_8c.html#a92153e7221efdcd457735fe191039024", null ],
    [ "plP_getinitdriverlist", "plcore_8c.html#af4d4105be53d926e7dfe4e27b9ea3549", null ],
    [ "plP_gphy", "plcore_8c.html#ad297b2b9d2d2910c82738c092fd3e801", null ],
    [ "plP_gpixmm", "plcore_8c.html#a9b4c25e0104684b69146c2a2b53fddce", null ],
    [ "plP_gprec", "plcore_8c.html#ae9fccfe5d0e940c4fc23a113ebd6b4e1", null ],
    [ "plP_gradient", "plcore_8c.html#a7ae0cb11419920fbbb90e999bd640820", null ],
    [ "plP_grange", "plcore_8c.html#aa297cded85840cc10694d08344150ea6", null ],
    [ "plP_gsub", "plcore_8c.html#a5006507ed1514a48f0d26e41ba42a749", null ],
    [ "plP_gtimefmt", "plcore_8c.html#a29475461e33613a343131dcb02e86961", null ],
    [ "plP_gw3wc", "plcore_8c.html#a755afa15a4e42c0d16deb69ceddc3717", null ],
    [ "plP_hex2fci", "plcore_8c.html#a99c7073577aa3feda05b96e5dac0a791", null ],
    [ "plP_image", "plcore_8c.html#a49cb4f889b6918c113d8f1ee8d9ba00f", null ],
    [ "plP_init", "plcore_8c.html#a1c04ae2f68d0b377a5f6f6c97474498c", null ],
    [ "plP_line", "plcore_8c.html#a4f9a6519caa1e25137cf95fdd2e5860d", null ],
    [ "plP_polyline", "plcore_8c.html#a1aba6c2de9e2d7f7e74589b909e20a49", null ],
    [ "plP_sclp", "plcore_8c.html#ac32d67d524a27bf32953485ba7945977", null ],
    [ "plP_setphy", "plcore_8c.html#ae8214645167e67a08bb88b47fce20082", null ],
    [ "plP_setpxl", "plcore_8c.html#a66ef3b9f70c7befa6b4fe71f27c95813", null ],
    [ "plP_ssub", "plcore_8c.html#acdeacf2faf1b357ce2a5baa53da038c3", null ],
    [ "plP_state", "plcore_8c.html#a11cd58efcc72c46c2f934ddabfbb1a90", null ],
    [ "plP_swin", "plcore_8c.html#a93ba5ed9e5f7401b4f489dbd6758c8aa", null ],
    [ "plP_text", "plcore_8c.html#a60f08ea02ac98641d98af649f4da10ae", null ],
    [ "plP_tidy", "plcore_8c.html#a58a3581c01cee21a43d2cceb63861cac", null ],
    [ "plP_xgvpw", "plcore_8c.html#a196e425a581d271af68ac89071ffe190", null ],
    [ "plsbopH", "plcore_8c.html#aab7674b12187240cec16821bac2e5fcb", null ],
    [ "plsButtonEH", "plcore_8c.html#a0702eab256cac9072e40a8abf0c6f026", null ],
    [ "plSelectDev", "plcore_8c.html#a2352d5234d80883d3fb12372c4b700d5", null ],
    [ "plseopH", "plcore_8c.html#ac129be2b7075237e1c2cbe02b17f45a1", null ],
    [ "plsError", "plcore_8c.html#a735a54509c0c36b8a422374956ab46eb", null ],
    [ "plsfile", "plcore_8c.html#a8808f0907cb6529c89814b50c3aecda9", null ],
    [ "plsKeyEH", "plcore_8c.html#af0db27668cdbf39f1142cafc553f2de4", null ],
    [ "plstrm_init", "plcore_8c.html#a659bd03250b8cee5bc6dd32d0e81a200", null ],
    [ "plsxwin", "plcore_8c.html#a66a64a268847626e8c5e3649c4a36f4b", null ],
    [ "setdef_didev", "plcore_8c.html#a8500175cb5a72d10ed696bb96b802c73", null ],
    [ "setdef_diori", "plcore_8c.html#a6f2fe9db9918179b9028d8750004b39f", null ],
    [ "setdef_diplt", "plcore_8c.html#a5c2e1360f92c85cdde0866c822aeacb3", null ],
    [ "text2fci", "plcore_8c.html#ab5ed11ea9469ea9e4c5e1d8c5fb3e488", null ],
    [ "text2num", "plcore_8c.html#a005b7ebf9131c9ee0266602f3830f6d5", null ],
    [ "ucs4_to_utf8", "plcore_8c.html#aa6086478e2def7762450396bc71bc316", null ],
    [ "utf8_to_ucs4", "plcore_8c.html#a09b8b47af09160143a9e7244f79f03b9", null ],
    [ "foo", "plcore_8c.html#a819b717d29c6c488a332fefeeb3815ba", null ],
    [ "plP_greek_mnemonic", "plcore_8c.html#a4e3b3e20867b5eb19bc1ea4014e0c7ec", null ],
    [ "unicode_buffer", "plcore_8c.html#abc490f7a97e538ac7fa480678647fbfd", null ]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/plcore_8c.js <==
var plcore_8c =
[
    [ "BUFFER2_SIZE", "plcore_8c.html#ae0194ede027b49240cc0a7d722d581ed", null ],
    [ "BUFFER_SIZE", "plcore_8c.html#a6b20d41d6252e9871430c242cb1a56e7", null ],
    [ "DEBUG", "plcore_8c.html#ad72dbcf6d0153db1b8d8a58001feed83", null ],
    [ "dirent", "plcore_8c.html#a89957e9be80ef12a50eb4eca72ecd888", null ],
    [ "DRVSPEC_SIZE", "plcore_8c.html#aeccd9f754e3d81d10b32e0449323bafb", null ],
    [ "N_TextLookupTable", "plcore_8c.html#a43b4218c140030f4050f49fe14af41f4", null ],
    [ "NAMLEN", "plcore_8c.html#abb80c1eb90e546dbdc94f79e74ffd787", null ],
    [ "NEED_PLDEBUG", "plcore_8c.html#ad92ef941bb38ab1d2af3bce830fd47c9", null ],
    [ "AT_BOP", "plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55bacef624e37a53fb2a68d5c9a08b8a7ccf", null ],
    [ "DRAWING", "plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba958d99ff23a05900a8e5cf1a56055098", null ],
    [ "AT_EOP", "plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba74ab759c0ff9e51f5df3638a75023e6d", null ],
    [ "alternate_unicode_processing", "plcore_8c.html#a684791a3ca4a8011f221eeb3d36181f2", null ],
    [ "c_plcpstrm", "plcore_8c.html#a808e7856a0bef6d71c2309abea207c78", null ],
    [ "c_plend", "plcore_8c.html#a057806120a84ea1da3ffef67bff47491", null ],
    [ "c_plend1", "plcore_8c.html#a82d7eca932a870b8724abf64609be0ce", null ],
    [ "c_plfamadv", "plcore_8c.html#ad03888fe21e744719a5215b2f71b0516", null ],
    [ "c_plflush", "plcore_8c.html#aa68be25daff0516a7e2a0fac0bdfdd9a", null ],
    [ "c_plfontld", "plcore_8c.html#adca30e3b9bfef3b0ac9bcb394e15552c", null ],
    [ "c_plgchr", "plcore_8c.html#a63e2da015640c52a9999c55342b646fc", null ],
    [ "c_plgcompression", "plcore_8c.html#a9b95f1be421f4ffb0ecdd690acc51991", null ],
    [ "c_plgdev", "plcore_8c.html#a730e264140174728e5a9370500dd98b9", null ],
    [ "c_plgdidev", "plcore_8c.html#a148607d52aba56ef94c79a572e72749c", null ],
    [ "c_plgdiori", "plcore_8c.html#af7d3028d40a2a370eaf59b252e70129d", null ],
    [ "c_plgdiplt", "plcore_8c.html#ab7394daabcb9894bf7805308428c71e6", null ],
    [ "c_plgfam", "plcore_8c.html#a7601ac2a53c8ee1385cace0dc8a17d8b", null ],
    [ "c_plgfci", "plcore_8c.html#a83276fc9443a12048337c947819acea3", null ],
    [ "c_plgfnam", "plcore_8c.html#a75a7c204e1e884ee546e0baf88917f54", null ],
    [ "c_plglevel", "plcore_8c.html#a0c11fe456b55f9f0062415101cb9dfc8", null ],
    [ "c_plgpage", "plcore_8c.html#ad9555920fc7673920b6862e38d049191", null ],
    [ "c_plgstrm", "plcore_8c.html#aa6ecda5740335b215a4c6ec05aefe2fc", null ],
    [ "c_plgver", "plcore_8c.html#a2f50780df4b008a23d5c881641bc4838", null ],
    [ "c_plgvpd", "plcore_8c.html#ae5b0ed045773267243e3c74dd6526ae6", null ],
    [ "c_plgvpw", "plcore_8c.html#a64c2cee6f05cffdd2bc9c8b85c94b662", null ],
    [ "c_plgxax", "plcore_8c.html#a7e9b55b0ec2ae5525591f6fede113a9e", null ],
    [ "c_plgyax", "plcore_8c.html#ae147ba26e63df579fc9434c6c4cbc3cd", null ],
    [ "c_plgzax", "plcore_8c.html#a720bd62d527c1db65f35b344c03140e9", null ],
    [ "c_plinit", "plcore_8c.html#ab4936c1ab86820efcc43ba6d2d3e98bd", null ],
    [ "c_plmkstrm", "plcore_8c.html#ad60759694b61589b021ed95fe5299be7", null ],
    [ "c_plprec", "plcore_8c.html#ab2ffc34fab68c711d27aa721b0153d13", null ],
    [ "c_plreplot", "plcore_8c.html#a521895943ac77a578e66673a7a26ad2a", null ],
    [ "c_plscompression", "plcore_8c.html#a1ff4a020fb7e8ba96cb65c1749c077dd", null ],
    [ "c_plsdev", "plcore_8c.html#a9a13e7e0f04135f388717f627b6ed322", null ],
    [ "c_plsdidev", "plcore_8c.html#a3badb62009aef6999810c0d10d20516c", null ],
    [ "c_plsdimap", "plcore_8c.html#a51cb3f6fef775355b2b1580e1307ea26", null ],
    [ "c_plsdiori", "plcore_8c.html#acb67a49f12188daff82a2ec48978d2df", null ],
    [ "c_plsdiplt", "plcore_8c.html#a3bdd5f699d95e79d94e39448172e10c2", null ],
    [ "c_plsdiplz", "plcore_8c.html#ae33ad6c295d7c38c342fc665baee5ba1", null ],
    [ "c_plsesc", "plcore_8c.html#ad34d123d1b509c1da24e3ba401787d43", null ],
    [ "c_plsfam", "plcore_8c.html#a21aa2add88af9fa23a2ea3d031637755", null ],
    [ "c_plsfci", "plcore_8c.html#ac161115689719887c26b967f5ae8cc17", null ],
    [ "c_plsfnam", "plcore_8c.html#a1067db8a7df729d967bd64bbb4db32aa", null ],
    [ "c_plsmem", "plcore_8c.html#a5332cad59cd8e8424274d43a50c869db", null ],
    [ "c_plsmema", "plcore_8c.html#a7c4475f45e1b579af4b147f4cd5df58a", null ],
    [ "c_plsori", "plcore_8c.html#aece5565b63831fdba73b39c9a1f2ea1e", null ],
    [ "c_plspage", "plcore_8c.html#ad12f661799506496b1172332fd00e54f", null ],
    [ "c_plspause", "plcore_8c.html#a6a3b37f7cfbc34a552b4bf20308aa79d", null ],
    [ "c_plsstrm", "plcore_8c.html#aa1e9f431367c59a195f1a8cd9e2227c1", null ],
    [ "c_plssub", "plcore_8c.html#a3f508d621ee47b67d42f656edc0aa9c7", null ],
    [ "c_plstar", "plcore_8c.html#a3d15fa158e627ba1582fbad9271c797b", null ],
    [ "c_plstart", "plcore_8c.html#a294125dcb910f34b5562b6b41175359a", null ],
    [ "c_plstransform", "plcore_8c.html#a1ef1de22d0c5557187f25d20a5193fca", null ],
    [ "c_plsxax", "plcore_8c.html#aca008e616ba21f5d1f51618e0cfe9064", null ],
    [ "c_plsyax", "plcore_8c.html#aae7ebd3c9503d19ef16d9dbe0236e709", null ],
    [ "c_plszax", "plcore_8c.html#a3170cad72924f63f2fe03055f355cb95", null ],
    [ "c_plwidth", "plcore_8c.html#a7e8aa99d537c6041b805f360f5c2b81c", null ],
    [ "calc_didev", "plcore_8c.html#a26b8467bc1909781bdc9d74960d6d238", null ],
    [ "calc_dimap", "plcore_8c.html#a0e92f358a43acd5c2fe68e40433a7b9c", null ],
    [ "calc_diori", "plcore_8c.html#a7a2547ac4d7cc4edab10361ca81f983d", null ],
    [ "calc_diplt", "plcore_8c.html#aaa88349701dbf79cbe3459271e11913d", null ],
    [ "difilt", "plcore_8c.html#a663c143ac825caaef262f7ca77b3c019", null ],
    [ "difilt_clip", "plcore_8c.html#a2e6bd1707a0ea6e38454e364c420eb5e", null ],
    [ "encode_unicode", "plcore_8c.html#a6d3865755042b46ea414ba430a72846d", null ],
    [ "grfill", "plcore_8c.html#a859a0f4ec99bc066171dda65bbd7172c", null ],
    [ "grgradient", "plcore_8c.html#a7498b6e873f50e540504be66a4e8dde0", null ],
    [ "grline", "plcore_8c.html#a05047fa1f14551c0664c4d5192eb4b1a", null ],
    [ "grpolyline", "plcore_8c.html#a1dd1a3d65c1c7e9912c5da15e82f1ba6", null ],
    [ "pl_cpcolor", "plcore_8c.html#a56a35e11c4db4ea3764ae38eae890213", null ],
    [ "pldi_ini", "plcore_8c.html#a5aed70fa2baf0c2959c6023c6c926cd1", null ],
    [ "pldid2pc", "plcore_8c.html#aba7dcb97d5f032a445cfa3ac2c68c999", null ],
    [ "pldip2dc", "plcore_8c.html#a2027ec7ca75362338c45ea442c421436", null ],
    [ "plDispatchSequencer", "plcore_8c.html#a11cad0979d02e025acd0ba8915be12db", null ],
    [ "plgdevlst", "plcore_8c.html#a497b257f1e4edd05ca465a9929c99adb", null ],
    [ "plgDevs", "plcore_8c.html#a06787374c7a4b94b10f6ee71cd9147ab", null ],
    [ "plgesc", "plcore_8c.html#adb3b82d6aa6dae20bcfb8d9b750d385a", null ],
    [ "plgfile", "plcore_8c.html#ad3cb9a03dc019cb768badd38f26bce13", null ],
    [ "plgFileDevs", "plcore_8c.html#ae06fd6c139fb7f7927d28d26ee72adbd", null ],
    [ "plgpls", "plcore_8c.html#a5225c4de186e1a9dc679dc5c05551afb", null ],
    [ "plInBuildTree", "plcore_8c.html#a62e41d0f4b6fc6b53806402f16eb7cca", null ],
    [ "plInitDispatchTable", "plcore_8c.html#a747167c361c0eb00627c064f7f9c1eda", null ],
    [ "pllib_devinit", "plcore_8c.html#ae6619e8f9a247bb9f9eac77a2960cd8a", null ],
    [ "pllib_init", "plcore_8c.html#a091b5e6a195184c0cdde351670ed27b0", null ],
    [ "plLoadDriver", "plcore_8c.html#aef0054e2662ce74c5245fbdfae25bd3f", null ],
    [ "plP_bop", "plcore_8c.html#a2a29b38531e5884f2380d3e4b213ed8b", null ],
    [ "plP_checkdriverinit", "plcore_8c.html#aca45ddfcca5aed11ab19be6911e4ebc1", null ],
    [ "plP_eop", "plcore_8c.html#a385cdde6b350434e911fb63b27f5c026", null ],
    [ "plP_esc", "plcore_8c.html#adaaf1b468021f85a88997d5518aa709a", null ],
    [ "plP_fci2hex", "plcore_8c.html#a0d847defa496f25716fd0d031891ac6d", null ],
    [ "plP_fill", "plcore_8c.html#aeb2f57f5e4b95188ab95363895f17573", null ],
    [ "plP_gclp", "plcore_8c.html#aba8054e2bee48e6669cb5143733d1b6d", null ],
    [ "plP_gdom", "plcore_8c.html#a92153e7221efdcd457735fe191039024", null ],
    [ "plP_getinitdriverlist", "plcore_8c.html#af4d4105be53d926e7dfe4e27b9ea3549", null ],
    [ "plP_gphy", "plcore_8c.html#ad297b2b9d2d2910c82738c092fd3e801", null ],
    [ "plP_gpixmm", "plcore_8c.html#a9b4c25e0104684b69146c2a2b53fddce", null ],
    [ "plP_gprec", "plcore_8c.html#ae9fccfe5d0e940c4fc23a113ebd6b4e1", null ],
    [ "plP_gradient", "plcore_8c.html#a7ae0cb11419920fbbb90e999bd640820", null ],
    [ "plP_grange", "plcore_8c.html#aa297cded85840cc10694d08344150ea6", null ],
    [ "plP_gsub", "plcore_8c.html#a5006507ed1514a48f0d26e41ba42a749", null ],
    [ "plP_gtimefmt", "plcore_8c.html#a29475461e33613a343131dcb02e86961", null ],
    [ "plP_gw3wc", "plcore_8c.html#a755afa15a4e42c0d16deb69ceddc3717", null ],
    [ "plP_hex2fci", "plcore_8c.html#a99c7073577aa3feda05b96e5dac0a791", null ],
    [ "plP_image", "plcore_8c.html#a49cb4f889b6918c113d8f1ee8d9ba00f", null ],
    [ "plP_init", "plcore_8c.html#a1c04ae2f68d0b377a5f6f6c97474498c", null ],
    [ "plP_line", "plcore_8c.html#a4f9a6519caa1e25137cf95fdd2e5860d", null ],
    [ "plP_polyline", "plcore_8c.html#a1aba6c2de9e2d7f7e74589b909e20a49", null ],
    [ "plP_sclp", "plcore_8c.html#ac32d67d524a27bf32953485ba7945977", null ],
    [ "plP_setphy", "plcore_8c.html#ae8214645167e67a08bb88b47fce20082", null ],
    [ "plP_setpxl", "plcore_8c.html#a66ef3b9f70c7befa6b4fe71f27c95813", null ],
    [ "plP_ssub", "plcore_8c.html#acdeacf2faf1b357ce2a5baa53da038c3", null ],
    [ "plP_state", "plcore_8c.html#a11cd58efcc72c46c2f934ddabfbb1a90", null ],
    [ "plP_swin", "plcore_8c.html#a93ba5ed9e5f7401b4f489dbd6758c8aa", null ],
    [ "plP_text", "plcore_8c.html#a60f08ea02ac98641d98af649f4da10ae", null ],
    [ "plP_tidy", "plcore_8c.html#a58a3581c01cee21a43d2cceb63861cac", null ],
    [ "plP_wait", "plcore_8c.html#ac29bb39abc488ef9443f228ce8e6cf3e", null ],
    [ "plP_xgvpw", "plcore_8c.html#a196e425a581d271af68ac89071ffe190", null ],
    [ "plsbopH", "plcore_8c.html#aab7674b12187240cec16821bac2e5fcb", null ],
    [ "plsButtonEH", "plcore_8c.html#a0702eab256cac9072e40a8abf0c6f026", null ],
    [ "plsdevdata", "plcore_8c.html#a8644bf1c2965d36ae28650a25075d316", null ],
    [ "plSelectDev", "plcore_8c.html#a2352d5234d80883d3fb12372c4b700d5", null ],
    [ "plseopH", "plcore_8c.html#ac129be2b7075237e1c2cbe02b17f45a1", null ],
    [ "plsError", "plcore_8c.html#a735a54509c0c36b8a422374956ab46eb", null ],
    [ "plsfile", "plcore_8c.html#a8808f0907cb6529c89814b50c3aecda9", null ],
    [ "plsKeyEH", "plcore_8c.html#af0db27668cdbf39f1142cafc553f2de4", null ],
    [ "plstrm_init", "plcore_8c.html#a659bd03250b8cee5bc6dd32d0e81a200", null ],
    [ "plsxwin", "plcore_8c.html#a66a64a268847626e8c5e3649c4a36f4b", null ],
    [ "setdef_didev", "plcore_8c.html#a8500175cb5a72d10ed696bb96b802c73", null ],
    [ "setdef_diori", "plcore_8c.html#a6f2fe9db9918179b9028d8750004b39f", null ],
    [ "setdef_diplt", "plcore_8c.html#a5c2e1360f92c85cdde0866c822aeacb3", null ],
    [ "text2fci", "plcore_8c.html#ab5ed11ea9469ea9e4c5e1d8c5fb3e488", null ],
    [ "text2num", "plcore_8c.html#a005b7ebf9131c9ee0266602f3830f6d5", null ],
    [ "ucs4_to_utf8", "plcore_8c.html#aa6086478e2def7762450396bc71bc316", null ],
    [ "utf8_to_ucs4", "plcore_8c.html#a09b8b47af09160143a9e7244f79f03b9", null ],
    [ "foo", "plcore_8c.html#a819b717d29c6c488a332fefeeb3815ba", null ],
    [ "plP_greek_mnemonic", "plcore_8c.html#a4e3b3e20867b5eb19bc1ea4014e0c7ec", null ],
    [ "unicode_buffer_static", "plcore_8c.html#ae30c62e1206957286d289d92feddb783", null ]
];
